@@ -2,13 +2,14 @@
 #'
 #' \code{dwplot} is a function for quickly and easily generating dot-and-whisker plots of regression models saved in tidy data frames.
 #'
-#' @param x Either a model object to be tidied with \code{\link[broomExtra]{tidy_parameters}}, or a list of such model objects, or a tidy data frame of regression results (see 'Details').
+#' @param x Either a model object to be tidied with \code{\link[broom]{tidy}}, or a list of such model objects, or a tidy data frame of regression results (see 'Details').
 #' @param ci A number indicating the level of confidence intervals; the default is .95.
 #' @param dodge_size A number indicating how much vertical separation should be between different models' coefficients when multiple models are graphed in a single plot.  Lower values tend to look better when the number of independent variables is small, while a higher value may be helpful when many models appear on the same plot; the default is 0.4.
-#' @param order_vars A vector of variable names that specifies the order in which the variables are to appear along the y-axis of the plot.
+#' @param vars_order A vector of variable names that specifies the order in which the variables are to appear along the y-axis of the plot. Note that the order will be overwritten by \code{\link[dotwhisker]{relabel_predictors}}, if the function is following called.
 #' @param show_intercept A logical constant indicating whether the coefficient of the intercept term should be plotted.
 #' @param margins A logical value indicating whether presenting the average marginal effects of the estimates. See the Details for more information.
 #' @param model_name The name of a variable that distinguishes separate models within a tidy data frame.
+#' @param model_order A character vector defining the order of the models when multiple models are involved.
 #' @param style Either \code{"dotwhisker"} or \code{"distribution"}. \code{"dotwhisker"}, the default, shows the regression coefficients' point estimates as dots with confidence interval whiskers.  \code{"distribution"} shows the normal distribution with mean equal to the point estimate and standard deviation equal to the standard error, underscored with a confidence interval whisker.
 #' @param by_2sd When x is model object or list of model objects, should the coefficients for predictors that are not binary be rescaled by twice the standard deviation of these variables in the dataset analyzed, per Gelman (2008)?  Defaults to \code{FALSE}.  Note that when x is a tidy data frame, one can use \code{\link[dotwhisker]{by_2sd}} to rescale similarly.
 #' @param vline A \code{geom_vline()} object, typically with \code{xintercept = 0}, to be drawn behind the coefficients.
@@ -16,18 +17,18 @@
 #' @param whisker_args When \code{style} is "dotwhisker", a list of arguments specifying the appearance of the whiskers representing the confidence intervals.  For supported arguments, see \code{\link[ggstance]{geom_linerangeh}}.
 #' @param dist_args When \code{style} is "distribution", a list of arguments specifying the appearance of normally distributed regression estimates.  For supported arguments, see \code{\link[ggplot2]{geom_polygon}}.
 #' @param line_args When \code{style} is "distribution", a list of arguments specifying the appearance of the line marking the confidence interval beneath the normal distribution.  For supported arguments, see \code{\link[ggstance]{geom_linerangeh}}.
-#' @param \dots Extra arguments to pass to \code{\link[broomExtra]{tidy_parameters}}.
+#' @param \dots Extra arguments to pass to \code{\link[parameters]{parameters}}.
 #'
-#' @details \code{dwplot} visualizes regression model objects or regression results saved in tidy data frames by, e.g., \code{\link[broomExtra]{tidy_parameters}} as dot-and-whisker plots generated by \code{\link[ggplot2]{ggplot}}.
+#' @details \code{dwplot} visualizes regression model objects or regression results saved in tidy data frames as dot-and-whisker plots generated by \code{\link[ggplot2]{ggplot}}.
 #'
 #' Tidy data frames to be plotted should include the variables \code{term} (names of predictors), \code{estimate} (corresponding estimates of coefficients or other quantities of interest), \code{std.error} (corresponding standard errors), and optionally \code{model} (when multiple models are desired on a single plot; a different name for this last variable may be specified using the model_name argument).
 #' In place of \code{std.error} one may substitute \code{conf.low} (the lower bounds of the confidence intervals of each estimate) and \code{conf.high} (the corresponding upper bounds).
 #'
-#' For convenience, \code{dwplot} also accepts as input those model objects that can be tidied by \code{\link[broomExtra]{tidy_parameters}}, or a list of such model objects.
+#' For convenience, \code{dwplot} also accepts as input those model objects that can be tidied by \code{\link[broom]{tidy}} (or \code{\link[broomExtra]{tidy_parameters}}, \code{\link[parameters]{parameters}} (with proper formatting)), or a list of such model objects.
 #'
-#' By default, the plot will display 95-percent confidence intervals.  To display a different interval when passing a model object or objects, specify a \code{ci} argument to pass to \code{\link[broomExtra]{tidy_parameters}}.  When passing a data frame of results, include the variables \code{conf.low} and \code{conf.high} describing the bounds of the desired interval.
+#' By default, the plot will display 95-percent confidence intervals.  To display a different interval when passing a model object or objects, specify a \code{ci} argument.  When passing a data frame of results, include the variables \code{conf.low} and \code{conf.high} describing the bounds of the desired interval.
 #'
-#' Because the function can take a data frame as input, it is easily employed for a wide range of models, including those not supported by \code{\link[broomExtra]{tidy_parameters}}.
+#' Because the function can take a data frame as input, it is easily employed for a wide range of models, including those not supported by \code{broom}, \code{broomExtra}, or \code{parameters}.
 #' And because the output is a \code{ggplot} object, it can easily be further customized with any additional arguments and layers supported by \code{ggplot2}.
 #' Together, these two features make \code{dwplot} extremely flexible.
 #'
@@ -41,7 +42,7 @@
 #' @return The function returns a \code{ggplot} object.
 #'
 #' @import ggplot2
-#' @importFrom broomExtra tidy_parameters
+#' @importFrom parameters parameters standardize_names
 #' @importFrom dplyr "%>%" filter arrange left_join full_join bind_rows group_by if_else mutate distinct
 #' @importFrom stats qnorm reorder model.matrix
 #' @importFrom ggstance geom_pointrangeh position_dodgev GeomLinerangeh
@@ -88,10 +89,11 @@
 dwplot <- function(x,
                    ci = .95,
                    dodge_size = .4,
-                   order_vars = NULL,
+                   vars_order = NULL,
                    show_intercept = FALSE,
                    margins = FALSE,
                    model_name = "model",
+                   model_order = NULL,
                    style = c("dotwhisker", "distribution"),
                    by_2sd = FALSE,
                    vline = NULL,
@@ -126,8 +128,9 @@ dwplot <- function(x,
     if (model_name %in% names(df)) {
         dfmod <- df[[model_name]]
         n_models <- length(unique(dfmod))
+        l_models <- if(is.null(model_order)) unique(dfmod) else model_order
         ## re-order/restore levels by order in data set
-        df[[model_name]] <- factor(dfmod, levels = unique(dfmod))
+        df[[model_name]] <- factor(dfmod, levels = rev(l_models))
     } else {
         if (length(df$term) == n_vars) {
             df[[model_name]] <- factor("one")
@@ -143,8 +146,8 @@ dwplot <- function(x,
     mod_names <- unique(df[[model_name]])
 
     # Specify order of variables if an order is provided
-    if (!is.null(order_vars)) {
-        df$term <- factor(df$term, levels = order_vars)
+    if (!is.null(vars_order)) {
+        df$term <- factor(df$term, levels = vars_order)
         df <- df[order(df$term),] %>% filter(!is.na(term))
     }
 
@@ -188,6 +191,8 @@ dwplot <- function(x,
                         line_args = line_args,
                         dist_args = dist_args) +
             scale_y_continuous(breaks = unique(df$y_ind), labels = var_names) +
+            guides(color = guide_legend(reverse = TRUE),
+                   fill = guide_legend(reverse = TRUE)) +
             ylab("") + xlab("")
 
     } else {
@@ -205,6 +210,7 @@ dwplot <- function(x,
                 segment_args = segment_args,
                 dodge_size = dodge_size
             ) +
+            guides(color = guide_legend(reverse = TRUE)) +
             ylab("") + xlab("")
     }
 
@@ -215,9 +221,10 @@ dwplot <- function(x,
 
     p$args <- list(
         dodge_size = dodge_size,
-        order_vars = order_vars,
+        vars_order = vars_order,
         show_intercept = show_intercept,
         model_name = model_name,
+        model_order = model_order,
         style = style,
         by_2sd = FALSE,
         vline = vline,
@@ -266,7 +273,7 @@ dw_tidy <- function(x, ci, by_2sd, margins,...) {
                            statistic = z,
                            p.value = p)
             }else{
-                df <- broomExtra::tidy_parameters(x, conf.int = TRUE, ...)
+                df <- standardize_names(parameters(x, ci, conf.int = TRUE, ...), style = "broom")
             }
 
             if (by_2sd) {
@@ -290,7 +297,7 @@ dw_tidy <- function(x, ci, by_2sd, margins,...) {
                                                         statistic = z,
                                                         p.value = p)
                                          }else{
-                                             df <- broomExtra::tidy_parameters(x, conf.int = TRUE, ...)
+                                             df <- standardize_names(parameters(x, ci, conf.int = TRUE, ...), style = "broom")
                                          }
                                          dotwhisker::by_2sd(df, dataset = get_dat(x))
                                      }) %>%
@@ -309,7 +316,7 @@ dw_tidy <- function(x, ci, by_2sd, margins,...) {
                                                         statistic = z,
                                                         p.value = p)
                                          }else{
-                                             df <- broomExtra::tidy_parameters(x, conf.int = TRUE, ...)
+                                             df <- standardize_names(parameters(x, ci, conf.int = TRUE, ...), style = "broom")
                                          }
                                      }) %>%
                     mutate(model = if_else(
